Attribute VB_Name = "MPPluginConst"
'//////////////////////////////////////////////////////////////////////
'//                                                                  //
'// File: MPPluginConst.def                                          //
'// Content: MsgPlus! plugin Visual Basic 6 constants and functions  //
'// Author: Patchou                                                  //
'//                                                                  //
'// Last Update: 2005/08/15                                          //
'//                                                                  //
'//////////////////////////////////////////////////////////////////////


'//////////////////////////////////////////////////////////////////////
'//                                                                  //
'// Messenger Plus! control characters                               //
'//                                                                  //
'//////////////////////////////////////////////////////////////////////

'//////////////////////////////////////////////////////////////////////
'//                                                                  //
'// The Notify control character is for exclusive use by plugins. It //
'// is generally inserted by plugin commands. This code must be at   //
'// the beginning of a message, must be transformed to a string with //
'// Chr() and must be followed by a 5 characters notify code unique  //
'// to your plugin.                                                  //
'//                                                                  //
'// Example: "XsamplHello!" (where "X" is the 0x12 character)        //
'// When received, the user will only see "Hello!" and               //
'// ReceiveNotify() will be called with "sampl" in sNotifyCode.      //
'//                                                                  //
'//////////////////////////////////////////////////////////////////////
Public Const nCCNotify As Long = &H12


'//////////////////////////////////////////////////////////////////////
'//                                                                  //
'// These control characters are used by Messenger Plus! to perform  //
'// different kind of actions. Feel free to use them in your own     //
'// messages. Note: these codes have a meaning ONLY when transformed //
'// with the Chr() function.                                         //
'//                                                                  //
'//////////////////////////////////////////////////////////////////////
Public Const nCCColor As Long = &H3       'Ctrl+K multi-format
Public Const nCCBold As Long = &H2        'Ctrl+B multi-format
Public Const nCCItalic As Long = &H5      'Ctrl+T multi-format
Public Const nCCUnderline As Long = &H1F  'Ctrl+U multi-format
Public Const nCCStrikeout As Long = &H6   'Ctrl+S multi-format
Public Const nCCReset As Long = &HF       'Ctrl+O multi-format

'When placed at the beginning of a message, this control character
'asks Messenger Plus! to temporary disable emoticons for the
'message.
Public Const nCCNoIcon As Long = &H8

'To display action message (/me), put these control characters at
'the beginning and at the end of your message.
Public Const sCCMeStart As String = "I "
Public Const sCCMeEnd As String = ""


'//////////////////////////////////////////////////////////////////////
'//                                                                  //
'// These strings can be used when a service name or a service ID    //
'// is required as parameter of a function of the Messenger API.     //
'//                                                                  //
'//////////////////////////////////////////////////////////////////////
Public Const sMessengerServiceName As String = ".NET Messenger Service"
Public Const sMessengerServiceID As String = "{9b017612-c9f1-11d2-8d9f-0000f875c541}"


'//////////////////////////////////////////////////////////////////////
'//                                                                  //
'// Messenger Plus! utility functions                                //
'//                                                                  //
'//////////////////////////////////////////////////////////////////////

Private Const HWND_BROADCAST = &HFFFF
Private Declare Function RegisterWindowMessage Lib "user32" Alias "RegisterWindowMessageA" (ByVal lpString As String) As Long
Private Declare Function SendMessage Lib "user32" Alias "SendMessageA" (ByVal hWnd As Long, ByVal nMsg As Long, ByVal wParam As Long, ByVal lParam As Long) As Long


'//////////////////////////////////////////////////////////////////////
'//                                                                  //
'// The following declarations are used by the DisplayToast() and    //
'// AddEventEntry functions. It is not recommended to use either of  //
'// these structures directly.                                       //
'//                                                                  //
'//////////////////////////////////////////////////////////////////////
Private Type MPL_TOAST_INFO
    sTitle As Long
    sMessage As Long
    sProgram As Long
    sSoundFile As Long
    
    nReserved As Long
End Type

Private Type MPL_EVENTLOG_INFO
    sUser As Long
    sEvent As Long
   
    nReserved As Long
End Type



'//////////////////////////////////////////////////////////////////////
'//                                                                  //
'// Purpose: Display toast popups                                    //
'//                                                                  //
'// Definition:                                                      //
'//   If the plugin engine version is 3 or above (see Initialize()), //
'//   your plugin can call this function to display a toast popup.   //
'//   The function returns immediately, it doesn't wait for the      //
'//   toast to be displayed. You should use the DisplayToast         //
'//   function and not use the MPL_TOAST_INFO structure  yourself.   //
'//                                                                  //
'// Parameters:                                                      //
'//   * sMessage: the text that will be displayed in the middle of   //
'//     the toast. If the text is too long to fit the window, it     //
'//     will be truncated.                                           //
'//   * sTitle: the title displayed on top of the toast. If NULL,    //
'//     the default title is displayed.                              //
'//   * sProgram: a program, or web link, that will be executed if   //
'//     the user clicks on the toast. If NULL, clicking on the toast //
'//     will do nothing. If this parameter is an email, Messenger    //
'//     Plus! will attempt to start a new chat with the user.        //
'//   * bPlaySound: set to true if you want Messenger Plus! to play  //
'//     the default sound associated for notifications in the        //
'//     preferences of the user.                                     //
'//                                                                  //
'//   Note: as the user may have configured Messenger Plus! not to   //
'//   display notifications when he/she is busy, do not assume that  //
'//   the toast will always be displayed.                            //
'//                                                                  //
'//   Technical Note: the message must be sent from the same thread  //
'//   Initialize() was called, else, Messenger Plus! will reject the //
'//   call for security reasons.                                     //
'//                                                                  //
'//////////////////////////////////////////////////////////////////////
Public Function DisplayToast(ByVal sMessage As String, ByVal sTitle As String, ByVal sProgram As String, ByVal bPlaySound As Boolean) As Boolean
    If (Len(sMessage) > 255) Then
        sMessage = Left(sMessage, 255)
    End If
    Dim info As MPL_TOAST_INFO
    info.sMessage = StrPtr(sMessage)

    If (Len(sTitle) < 1) Then
        info.sTitle = 0
    Else
       info.sTitle = StrPtr(sTitle)
    End If
    
    If (Len(sProgram) < 1) Then
        info.sProgram = 0
    Else
       info.sProgram = StrPtr(sProgram)
    End If
    
    If (bPlaySound) Then
        info.sSoundFile = -1
    Else
        info.sSoundFile = 0
    End If

    Dim nMsg As Long
    nMsg = RegisterWindowMessage("MessengerPlus_DisplayToast")

    Dim nResult As Long
    nResult = SendMessage(HWND_BROADCAST, nMsg, VarPtr(info), 1)
    DisplayToast = True 'There is no absolute way to detect if the function was successful
End Function



'//////////////////////////////////////////////////////////////////////
'//                                                                  //
'// Purpose: Change the display name of the user                     //
'//                                                                  //
'// Definition:                                                      //
'//   If the plugin engine version is 5 or above (see Initialize()), //
'//   your plugin can call this function to change the name of the   //
'//   user who is currently signed-in. The function returns          //
'//   immediately, it doesn't wait for the name to be actually       //
'//   changed by the server.                                         //
'//                                                                  //
'// Parameters:                                                      //
'//   * sNewName: the new name of the user. If it contains           //
'//     multi-formatcontrol codes, the name will be processed to     //
'//     make sure the server accepts the codes.                      //
'//                                                                  //
'//   Note: the server uses several rules to ensure the validity of  //
'//   a display name. If the change is rejected by the server, an    //
'//   error message will be displayed by Messenger.                  //
'//                                                                  //
'//   Technical Note: the message must be sent from the same thread  //
'//   Initialize() was called, else, Messenger Plus! will reject the //
'//   call for security reasons.                                     //
'//                                                                  //
'//////////////////////////////////////////////////////////////////////
Public Function SetNewName(ByVal sMessage As String) As Boolean
    Dim nMsg As Long
    nMsg = RegisterWindowMessage("MessengerPlus_SetName")

    Dim nResult As Long
    nResult = SendMessage(HWND_BROADCAST, nMsg, StrPtr(sMessage), 1)
    If (nResult = 0) Then
        SetNewName = False 'Can happen if the user if offline
    Else
        SetNewName = True 'There is no absolute way to detect if the function was successful
    End If
End Function




'//////////////////////////////////////////////////////////////////////
'//								     //
'// Purpose: Add an entry in the event log			     //
'//								     //
'// Definition:							     //
'//   If the plugin engine version is 7 or above (see Initialize()), //
'//   your plugin can call this function to add en entry in the	     //
'//   event log of Messenger Plus!. The entry is added both in the   //
'//   viewer and the event log file, depending the the user's	     //
'//   preferences.						     //
'//								     //
'// Parameters:							     //
'//   * sUser: text to be recorded as the user who generated the     //
'//     event. If this parameter is empty, Messenger Plus! sets a    //
'//     generic "from plugin" text in this field.		     //
'//   * sEvent: text of the event to be recorded. This parameter     //
'//     cannot be empty.					     //
'//								     //
'//   Technical Note: the message must be sent from the same thread  //
'//   Initialize() was called, else, Messenger Plus! will reject the //
'//   call for security reasons.				     //
'//								     //
'//////////////////////////////////////////////////////////////////////
Public Function AddEventEntry(ByVal sUser As String, ByVal sEvent As String) As Boolean
    Dim info As MPL_EVENTLOG_INFO

    If (Len(sUser) < 1) Then
        info.sUser = 0
    Else
       info.sUser = StrPtr(sUser)
    End If
    
    If (Len(sEvent) < 1) Then
        info.sEvent = 0
    Else
       info.sEvent = StrPtr(sEvent)
    End If
 
    Dim nMsg As Long
    nMsg = RegisterWindowMessage("MessengerPlus_AddEventLog")

    Dim nResult As Long
    nResult = SendMessage(HWND_BROADCAST, nMsg, VarPtr(info), 1)
    AddEventEntry = True 'The success of this function depends on the user's preferences
End Function
